@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.15';
+$VERSION = '1.16';
 
 #----------------------------------------------------------------------------
 
@@ -207,6 +207,10 @@ Method to manage the creation/update of the builder performance data file.
 
 Method to manage the creation of all the statistics graphs.
 
+=item * storage
+
+Method to return specific JSON data currently stored.
+
 =cut
 
 __PACKAGE__->mk_accessors(
@@ -305,6 +309,15 @@ sub make_graphs {
     $stats->create();
 }
 
+sub storage {
+    my $self = shift;
+    my $type = shift;
+    $self->_check_files();
+
+    my $stats = CPAN::Testers::WWW::Statistics::Pages->new(parent => $self);
+    $stats->storage_read($type);
+}
+
 =item * ranges
 
 Returns the specific date range array reference, as held in the configuration
